@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
 '''
 Testdata cotaining two very simple conceptschemes: trees and a few geographic concepts.
 
 .. versionadded:: 0.1.0
 '''
 
-from __future__ import unicode_literals
 
 from skosprovider.providers import DictionaryProvider
 
@@ -14,7 +12,8 @@ larch = {
     'uri': 'urn:x-skosprovider:trees/1',
     'labels': [
         {'type': 'prefLabel', 'language': 'en', 'label': 'The Larch'},
-        {'type': 'prefLabel', 'language': 'nl', 'label': 'De Lariks'}
+        {'type': 'prefLabel', 'language': 'nl', 'label': 'De Lariks'},
+        {'type': 'sortLabel', 'language': 'nl', 'label': 'c'}
     ],
     'notes': [
         {'type': 'definition', 'language': 'en', 'note': 'A type of tree.'}
@@ -31,6 +30,7 @@ chestnut = {
         {'type': 'prefLabel', 'language': 'en', 'label': 'The Chestnut'},
         {'type': 'altLabel', 'language': 'nl', 'label': 'De Paardekastanje'},
         {'type': 'altLabel', 'language': 'fr', 'label': 'la châtaigne'},
+        {'type': 'sortLabel', 'language': 'nl', 'label': 'a'}
     ],
     'notes': [
         {
@@ -48,7 +48,8 @@ species = {
     'uri': 'urn:x-skosprovider:trees/3',
     'labels': [
         {'type': 'prefLabel', 'language': 'en', 'label': 'Trees by species'},
-        {'type': 'prefLabel', 'language': 'nl', 'label': 'Bomen per soort'}
+        {'type': 'prefLabel', 'language': 'nl', 'label': 'Bomen per soort'},
+        {'type': 'sortLabel', 'language': 'nl', 'label': 'b'}
     ],
     'type': 'collection',
     'members': ['1', '2']
