@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 '''
 Testdata cotaining stylistic (eg. Gothic, Romanesque) and cultural periods 
 (eg. La Tène)
@@ -6,7 +5,6 @@ Testdata cotaining stylistic (eg. Gothic, Romanesque) and cultural periods
 .. versionadded:: 0.2.0
 '''
 
-from __future__ import unicode_literals
 
 from skosprovider.providers import DictionaryProvider
 from skosprovider.uri import UriPatternGenerator
